namespace eval ::VMDlite::lesson {
}

# Screen 1: ATP Mg

proc ::VMDlite::lesson::module1 { } {
	set ::VMDlite::lesson::currentFrame 1
	set ::VMDlite::lesson::totalFrames 6
	eval ::VMDlite::lesson::init
	eval ::VMDlite::lesson::refresh
	wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 1"

	mol new ${::VMDlite::lesson::directory}/ATPtoADPPi/ATPMg.pdb
    mol addfile ${::VMDlite::lesson::directory}/ATPtoADPPi/ATPMg.psf
    
    mol modstyle 0 [molinfo top] Licorice 0.3 30 30
    mol modcolor 0 [molinfo top] Name

	${::VMDlite::lesson::w}.textFrame.textBox insert end \
    "Slide ${::VMDlite::lesson::currentFrame}. Welcome to the ATP module!\n\nOn the screen you will see a molecule of ATP, also known as adenosine triphosphate, a biomolecule that provides living organisms with energy in a process reflected by the following chemical reaction: ATP + H2O => ADP + P_i + chemical energy.\n\n(Note that this reaction only occurs in water, giving the process the term \"hydrolysis\" from \"hydro-\" for \"water\" and \"-lysis\" for \"breaking\").\n\nIn this module, we will examine in further detail why this reaction occurs so often in nature."
}

# Screen 2: ADP Pi Mg

proc ::VMDlite::lesson::module2 { } {
	
    mol delete all

    set ::VMDlite::lesson::currentFrame 2
	eval ::VMDlite::lesson::refresh
	wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 2"
	
	${::VMDlite::lesson::w}.textFrame.textBox insert end \
    "Slide ${::VMDlite::lesson::currentFrame}. Press \"Play\" to see the hydrolysis of the ATP molecule. This reaction happens nearly instantaneously, so click \"Previous frame\" or \"Next frame\" to view the simulation more slowly. In the starting state, you see a water molecule near the ATP, ready to react with it.  Note how a portion of the ATP molecule detaches from the rest of the molecule in the next frame, having stolen an OH- group from the water (the other H+ is released and not shown). This portion is a phosphate group, one of the products in the previously discussed reaction.  Now free, you see that it sometimes even diffuses away from the ADP left behind (use the mouse wheel to zoom in and out).\n\nThis reaction happens in nature for a variety of complex reasons. One reason is due to the Second Law of Thermodynamics, which roughly states that the universe tends towards disorder, an especially important concept in biology, chemistry, and physics. When applied to this chemical reaction, we see that the left-hand side of the reaction describes a more ordered initial state, and that the right-hand side describes a less ordered state. Then according to the Second Law, the reaction tends to produce more ADP and P_i than ATP.\n\nThe second major reason for the release of energy is due to formation of new chemical bonds, which are more favorable energetically than the relatively weak bond holding the last phosphate in ATP."

	mol new ${::VMDlite::lesson::directory}/ATPtoADPPi/ADPPiMg.psf
	mol addfile ${::VMDlite::lesson::directory}/ATPtoADPPi/ADPPiMg5ns.dcd waitfor all
	
    animate goto 0

    ## tracks frame and makes it look like ATP in frame 0
    ## fakes bond breaking
    global vmd_frame
    trace variable vmd_frame([molinfo top]) w ::VMDlite::lesson::changeReps    	


    mol modstyle 0 [molinfo top] Lines 7.0
    mol modcolor 0 [molinfo top] Name
    mol modselect 0 [molinfo top] "not name MG H1G O4G"

    mol addrep [molinfo top]
    mol modstyle 1 [molinfo top] VDW 0.3 30
    mol modcolor 1 [molinfo top] ColorID 22
    mol modselect 1 [molinfo top] "name MG"

    mol addrep [molinfo top]
    mol modstyle 2 [molinfo top] DynamicBonds 2.4 0.1 30
    mol modcolor 2 [molinfo top] Name
    mol modselect 2 [molinfo top] "name O3B PG"

	# frame for time scale in DCD
	    ttk::frame ${::VMDlite::lesson::w}.scale \
        -relief sunken
    
    # actual scale
    ttk::scale ${::VMDlite::lesson::w}.scale.bar \
        -variable ::VMDlite::lesson::sliderPos \
        -from 0 -to 25  \
        -command ::VMDlite::lesson::setTime
    
    # buttons for manually moving through DCD
    ttk::button ${::VMDlite::lesson::w}.scale.play \
        -text "Play" \
        -command [list ::VMDlite::lesson::DCD 1]
    ttk::button ${::VMDlite::lesson::w}.scale.stop \
        -text "Stop" \
        -command [list ::VMDlite::lesson::DCD 0]
    ttk::button ${::VMDlite::lesson::w}.scale.stepBack \
        -text "Previous frame" \
        -command [list ::VMDlite::lesson::step prev]
    ttk::button ${::VMDlite::lesson::w}.scale.stepForward \
        -text "Next frame" \
        -command [list ::VMDlite::lesson::step next]

    # radio with buttons for representations
    ttk::frame ${::VMDlite::lesson::w}.radio \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio.label \
    -text "Representations"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.lines \
    -text "Lines" \
    -value "Lines" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Lines"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.licorice \
    -text "Licorice" \
    -value "Licorice" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Licorice"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.vdw \
    -text "VDW" \
    -value "VDW" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "VDW"}

    # pack
    pack ${::VMDlite::lesson::w}.scale \
        -before ${::VMDlite::lesson::w}.buttons \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2
    pack ${::VMDlite::lesson::w}.scale.bar \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -fill x
    pack ${::VMDlite::lesson::w}.scale.stepBack \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.play \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stop \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stepForward \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left

    # pack for radio gen. and radio.lines
    pack ${::VMDlite::lesson::w}.radio \
    -side top \
    -fill x \
    -expand true \
    -padx 2 -pady 2 \
    -ipadx 2 -ipady 2

    pack ${::VMDlite::lesson::w}.radio.label \
    ${::VMDlite::lesson::w}.radio.lines \
    ${::VMDlite::lesson::w}.radio.licorice \
    ${::VMDlite::lesson::w}.radio.vdw \
        -side left
    
    # initialize selection buttons
    ${::VMDlite::lesson::w}.radio.lines invoke
}

# highly specific proc for making ADP + Pi look like ATP in frame 0 only
# fakes bond breaking
proc ::VMDlite::lesson::changeReps { name element op } {
  global vmd_frame
  if { $vmd_frame([molinfo top]) < 1 } {
    mol modselect 0 [molinfo top] "not name H1G O4G"
  } else { 
    mol modselect 0 [molinfo top] "not water"
  }
}

# Screen 3: Myosin and ATP

proc ::VMDlite::lesson::module3 { } {
# ATP-myosin binding simulation

        mol delete all
##	graphics [molinfo top] delete all

    if {${::VMDlite::lesson::currentFrame} == 3} {
    scale by 0.05
    }

    set ::VMDlite::lesson::currentFrame 3
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 3"

    ${::VMDlite::lesson::w}.textFrame.textBox insert end \
"Slide ${::VMDlite::lesson::currentFrame}. On the screen you will see an ATP molecule binding to a molecule of myosin. Myosin is a protein present in all human cells, including at a very high density in muscle cells where it leads to contraction. If you use the scroll wheel to zoom out, you will see the full protein. We have highlighted a portion of the myosin protein called \"serine 237\" (an amino acid) that catalyzes hydrolysis of ATP by lowering the \"activation barrier\" (breaking bonds costs energy!). \n\nPress the \"Play\" button to observe just a few nanoseconds of dynamics of this protein.  Notice how the Mg2+ ion (blue sphere) is tightly held by an oxygen atom of serine 237 as well as those of ATP; the distances are indicated and are in units of Angstroms (1 Angstrom = 0.1 nm).  You may also click within the display window and move your mouse to rotate the system. Scroll the mouse wheel to zoom in and observe the simulation more closely.  Note how dynamic the atoms are!  Molecular systems are constantly undergoing stochastic (random) \"thermal motion\"."
	
    mol new ${::VMDlite::lesson::directory}/myosin1FMWATP/myosin1FMWATP.psf
	mol addfile ${::VMDlite::lesson::directory}/myosin1FMWATP/myosin1FMWATP5ns.dcd waitfor all

    mol modstyle 0 [molinfo top] Licorice 0.3 30 30 
    mol modcolor 0 [molinfo top] name
    mol modselect 0 [molinfo top] "resid 237 or resname ATP"

    mol addrep [molinfo top]
    mol modstyle 1 [molinfo top] VDW 0.3 30
    mol modcolor 1 [molinfo top] ColorID 22
    mol modselect 1 [molinfo top] "name MG"

    label add Bonds [molinfo top]/12180 [molinfo top]/12187
    label add Bonds [molinfo top]/12184 [molinfo top]/12187
    label add Bonds [molinfo top]/3755 [molinfo top]/12187

    mol addrep [molinfo top]
    mol modstyle 2 [molinfo top] NewCartoon
    mol modcolor 2 [molinfo top] Name
    mol modselect 2 [molinfo top] "protein"

    set sel [atomselect top "protein and resid 237"]
    set center [measure center ${sel}]
    ${sel} delete
    molinfo top set center [list ${center}]
    scale by 6.0
    translate to 0 0 0
    display update

    rotate z by -90
    rotate y by 90

    # frame for time scale in DCD
    ttk::frame ${::VMDlite::lesson::w}.scale \
        -relief sunken

	# actual scale
    ttk::scale ${::VMDlite::lesson::w}.scale.bar \
        -variable ::VMDlite::lesson::sliderPos \
        -from 0 -to 26 \
        -command ::VMDlite::lesson::setTime

    # buttons for manually moving through DCD
    ttk::button ${::VMDlite::lesson::w}.scale.play \
        -text "Play" \
        -command [list ::VMDlite::lesson::DCD 1]
    ttk::button ${::VMDlite::lesson::w}.scale.stop \
        -text "Stop" \
        -command [list ::VMDlite::lesson::DCD 0]
    ttk::button ${::VMDlite::lesson::w}.scale.stepBack \
        -text "Previous frame" \
        -command [list ::VMDlite::lesson::step prev]
    ttk::button ${::VMDlite::lesson::w}.scale.stepForward \
        -text "Next frame" \
        -command [list ::VMDlite::lesson::step next]


    # radio with buttons for representations for ATP
    ttk::frame ${::VMDlite::lesson::w}.radio \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio.label \
    -text "Representations (ATP + Ser237)"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.lines \
    -text "Lines" \
    -value "Lines" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Lines"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.licorice \
    -text "Licorice" \
    -value "Licorice" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Licorice"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.vdw \
    -text "VDW" \
    -value "VDW" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "VDW"}


    # radio with buttons for representations for protein
    ttk::frame ${::VMDlite::lesson::w}.radio2 \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio2.label \
    -text "Representations (protein)"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.lines \
    -text "Lines" \
    -value "Lines" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "Lines"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.licorice \
    -text "Licorice" \
    -value "Licorice" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "Licorice"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.vdw \
    -text "VDW" \
    -value "VDW" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "VDW"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.newcartoon \
    -text "New Cartoon" \
    -value "NewCartoon" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "NewCartoon"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.off \
    -text "off" \
    -value "off" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "off"}

    # pack    
    pack ${::VMDlite::lesson::w}.scale \
        -before ${::VMDlite::lesson::w}.buttons \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2
    pack ${::VMDlite::lesson::w}.scale.bar \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -fill x
    pack ${::VMDlite::lesson::w}.scale.stepBack \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.play \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stop \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stepForward \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    
    pack ${::VMDlite::lesson::w}.radio \
    -side top \
    -fill x \
    -expand true \
    -padx 2 -pady 2 \
    -ipadx 2 -ipady 2    

    pack ${::VMDlite::lesson::w}.radio.label \
        ${::VMDlite::lesson::w}.radio.lines \
        ${::VMDlite::lesson::w}.radio.licorice \
        ${::VMDlite::lesson::w}.radio.vdw \
        -side left  


    # second pack radio (general) statement here if needed
    pack ${::VMDlite::lesson::w}.radio2 \
    -side top \
    -fill x \
    -expand true \
    -padx 2 -pady 2 \
    -ipadx 2 -ipady 2    

    pack ${::VMDlite::lesson::w}.radio2.label \
        ${::VMDlite::lesson::w}.radio2.lines \
        ${::VMDlite::lesson::w}.radio2.licorice \
        ${::VMDlite::lesson::w}.radio2.vdw \
        ${::VMDlite::lesson::w}.radio2.newcartoon \
        ${::VMDlite::lesson::w}.radio2.off \
        -side left  

    # initialize selection buttons
    ${::VMDlite::lesson::w}.radio.licorice invoke
    ${::VMDlite::lesson::w}.radio2.newcartoon invoke

}	

# Screen 4: Myosin and ADP Pi

proc ::VMDlite::lesson::module4 { } {

    mol delete all

    if {${::VMDlite::lesson::currentFrame} == 4} {
    scale by 0.05
    }

    set ::VMDlite::lesson::currentFrame 4
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 4"
    
    ${::VMDlite::lesson::w}.textFrame.textBox insert end \
    "Slide ${::VMDlite::lesson::currentFrame}. In this panel, we are now looking at the active site immediately after hydrolysis of ATP into ADP + phosphate.  You can see the phosphate ion separated from the ADP, still strongly interacting with the Mg2+ ion.  Serine 237 is also nearby.  Click \"Next frame\" to observe what happens in the simulation. We see that serine 237 moves away from the Mg2+ ion quickly, due to the increased negative charge present in the phosphate ion.  The distance increases from 2.35 Angstroms (0.235 nm) to 4.65 Angstroms (0.464 nm) and remains at this larger distance for the rest of the simulation.\n\n What you just observed is the beginning of a process called \"the myosin powerstroke\".  Although this change in position of serine 237 seems too small to have any effect, it makes it easier for the phosphate ion to diffuse away through random motion (just as was seen in water alone!), which then permits a change in myosin's overall conformation (shape).  This is the so-called \"myosin power stroke\".  For a single muscle contraction, \~600 trillion ATP/second are hydrolyzed, generating a large movement as the sum of many tiny ones."

    mol new ${::VMDlite::lesson::directory}/myosin1FMWADPPi/myosin1FMWADPPi.psf
    mol addfile ${VMDlite::lesson::directory}/myosin1FMWADPPi/myosin1FMWADPPi5ns.dcd  waitfor all
	
    animate goto 0 

    mol modstyle 0 [molinfo top] Licorice 0.3 30 30
    mol modcolor 0 [molinfo top] name
    mol modselect 0 [molinfo top] "resid 237 or resname ADP PHOS"

    mol addrep [molinfo top]
    mol modstyle 1 [molinfo top] VDW 0.3 30
    mol modcolor 1 [molinfo top] ColorID 22
    mol modselect 1 [molinfo top] "name MG"

    mol addrep [molinfo top]
    mol modstyle 2 [molinfo top] NewCartoon
    mol modcolor 2 [molinfo top] Name
    mol modselect 2 [molinfo top] "protein"

    label add Bonds [molinfo top]/12180 [molinfo top]/12189
    label add Bonds [molinfo top]/12187 [molinfo top]/12189
    label add Bonds [molinfo top]/3755 [molinfo top]/12189

    set sel [atomselect top "protein and resid 237"]
    set center [measure center ${sel}]
    ${sel} delete
    molinfo top set center [list ${center}]
    scale by 6.0
    translate to 0 0 0
    display update

    rotate z by 45
    rotate y by 90

    # frame for time scale in DCD
    ttk::frame ${::VMDlite::lesson::w}.scale \
        -relief sunken

	# actual scale
    ttk::scale ${::VMDlite::lesson::w}.scale.bar \
        -variable ::VMDlite::lesson::sliderPos \
        -from 0 -to 26 \
        -command ::VMDlite::lesson::setTime

    # buttons for manually moving through DCD
    ttk::button ${::VMDlite::lesson::w}.scale.play \
        -text "Play" \
        -command [list ::VMDlite::lesson::DCD 1]
    ttk::button ${::VMDlite::lesson::w}.scale.stop \
        -text "Stop" \
        -command [list ::VMDlite::lesson::DCD 0]
    ttk::button ${::VMDlite::lesson::w}.scale.stepBack \
        -text "Previous frame" \
        -command [list ::VMDlite::lesson::step prev]
    ttk::button ${::VMDlite::lesson::w}.scale.stepForward \
        -text "Next frame" \
        -command [list ::VMDlite::lesson::step next]


    # radio with buttons for representations for ADP
    ttk::frame ${::VMDlite::lesson::w}.radio \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio.label \
    -text "Representations (ADP + Ser237)"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.lines \
    -text "Lines" \
    -value "Lines" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Lines"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.licorice \
    -text "Licorice" \
    -value "Licorice" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "Licorice"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.vdw \
    -text "VDW" \
    -value "VDW" \
    -variable ::VMDlite::lesson::rep1 \
    -command {::VMDlite::lesson::showRep 0 "VDW"}


    # radio with buttons for representations for protein
    ttk::frame ${::VMDlite::lesson::w}.radio2 \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio2.label \
    -text "Representations (protein)"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.lines \
    -text "Lines" \
    -value "Lines" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "Lines"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.licorice \
    -text "Licorice" \
    -value "Licorice" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "Licorice"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.vdw \
    -text "VDW" \
    -value "VDW" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "VDW"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.newcartoon \
    -text "New Cartoon" \
    -value "NewCartoon" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "NewCartoon"}
    ttk::radiobutton ${::VMDlite::lesson::w}.radio2.off \
    -text "off" \
    -value "off" \
    -variable ::VMDlite::lesson::rep2 \
    -command {::VMDlite::lesson::showRep 2 "off"}

    # pack    
    pack ${::VMDlite::lesson::w}.scale \
        -before ${::VMDlite::lesson::w}.buttons \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2
    pack ${::VMDlite::lesson::w}.scale.bar \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -fill x
    pack ${::VMDlite::lesson::w}.scale.stepBack \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.play \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stop \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stepForward \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    
    pack ${::VMDlite::lesson::w}.radio \
    -side top \
    -fill x \
    -expand true \
    -padx 2 -pady 2 \
    -ipadx 2 -ipady 2    

    pack ${::VMDlite::lesson::w}.radio.label \
        ${::VMDlite::lesson::w}.radio.lines \
        ${::VMDlite::lesson::w}.radio.licorice \
        ${::VMDlite::lesson::w}.radio.vdw \
        -side left  


    # second pack radio (general) statement here if needed
    pack ${::VMDlite::lesson::w}.radio2 \
    -side top \
    -fill x \
    -expand true \
    -padx 2 -pady 2 \
    -ipadx 2 -ipady 2    

    pack ${::VMDlite::lesson::w}.radio2.label \
        ${::VMDlite::lesson::w}.radio2.lines \
        ${::VMDlite::lesson::w}.radio2.licorice \
        ${::VMDlite::lesson::w}.radio2.vdw \
        ${::VMDlite::lesson::w}.radio2.newcartoon \
        ${::VMDlite::lesson::w}.radio2.off \
        -side left  

    # initialize selection buttons
    ${::VMDlite::lesson::w}.radio.licorice invoke
    ${::VMDlite::lesson::w}.radio2.newcartoon invoke


}	

# Screen 5: Multiple Choice

proc ::VMDlite::lesson::module5 { } {

	set ::VMDlite::lesson::currentFrame 5
	eval ::VMDlite::lesson::refresh
	wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 5"

	${::VMDlite::lesson::w}.textFrame.textBox insert end \
	"Slide ${::VMDlite::lesson::currentFrame}. Using the information you have just been given, which of the following is an accurate description of the relationship between the process of hydrolysis of ATP and the physical structure of the myosin protein as demonstrated in this module?\n\n

A. the production of chemical energy through the hydrolysis of ATP results in a structural change of the myosin protein that is consistent with its function in the body.\n
B. the breaking of a bond in ATP releases energy and moves the myosin protein.\n
C. ATP stores energy that is released when a chemical bond is broken and allows the myosin protein to change its structure."
    	
    # radio with buttons for multiple choice answers. Three radio buttons.
    ttk::frame ${::VMDlite::lesson::w}.radio \
    -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio.label \
    -text "Answer"

    ttk::radiobutton ${::VMDlite::lesson::w}.radio.a \
	-text "a" \
	-variable ::VMDlite::lesson::answer \
	-value "a" \
    -command ::VMDlite::lesson::emptyfunc

    ttk::radiobutton ${::VMDlite::lesson::w}.radio.b \
	-text "b" \
	-variable ::VMDlite::lesson::answer \
	-value "b" \
    -command ::VMDlite::lesson::emptyfunc

    ttk::radiobutton ${::VMDlite::lesson::w}.radio.c \
	-text "c" \
	-variable ::VMDlite::lesson::answer \
	-value "c" \
    -command ::VMDlite::lesson::emptyfunc

    # horizontal line for separation of scrollbar from buttons
    ttk::separator ${::VMDlite::lesson::w}.separator2 \
    -orient horizontal

    # pack
    pack ${::VMDlite::lesson::w}.radio \
    	-side top \
    	-fill x \
    	-expand true \
    	-padx 2 -pady 2 \
    	-ipadx 2 -ipady 2

    pack ${::VMDlite::lesson::w}.radio.label \
    	${::VMDlite::lesson::w}.radio.a \
    	${::VMDlite::lesson::w}.radio.b \
    	${::VMDlite::lesson::w}.radio.c \
    		-side left 
    		

    pack ${::VMDlite::lesson::w}.separator2 \
    	-fill x \
    	-pady 10 \
    	-side bottom \
    	-after ${::VMDlite::lesson::w}.radio \

    # initialize selection buttons 
    ${::VMDlite::lesson::w}.radio.a invoke
    ${::VMDlite::lesson::w}.radio.b invoke
    ${::VMDlite::lesson::w}.radio.c invoke
}

proc ::VMDlite::lesson::emptyfunc {} {}

# Screen 6	

proc ::VMDlite::lesson::module6 { } {

    mol delete all

	set ::VMDlite::lesson::currentFrame 6
	eval ::VMDlite::lesson::refresh
	wm title ${::VMDlite::lesson::w} "VMDlite -- ATP 6"
	
	${::VMDlite::lesson::w}.textFrame.textBox insert end \
	"Slide ${::VMDlite::lesson::currentFrame}. The correct answer is A.\n\nAnswers B and C include misconceptions about ATP hydrolysis.\n\nThe breaking of a chemical bond requires input of energy rather than directly releasing it.  It is the formation of new chemical bonds that releases energy. ATP hydrolysis is useful in energy production because it has a critically weak bond that, when broken, allows more stable bonds to be formed. Upon creation of these more stable bonds, a greater amount of energy is released than the amount of energy put in.  The myosin protein helps by enhancing the rate of bond breaking with serine 237.\n\n Answer B also includes an additional misconception: chemical reactions of this nature typically do not directly 'cause a molecule to move'.  Instead, they change the likelihood that random fluctuations of the protein, which are always present as we saw in the simulations, will be in a productive direction."

}	


#end 

